pub struct FuzzySet<D: Float, M: Float> { /* private fields */ }Expand description
A fuzzy set associates a linguistic term with a membership function.
Implementations
Sourceimpl<D: Float, M: Float> FuzzySet<D, M>
impl<D: Float, M: Float> FuzzySet<D, M>
Sourcepub fn new(
name: impl Into<String>,
membership_fn: Box<dyn MembershipFunction<D, M>>,
) -> Self
pub fn new( name: impl Into<String>, membership_fn: Box<dyn MembershipFunction<D, M>>, ) -> Self
Creates a new fuzzy set with a given name and membership function.
Sourcepub fn evaluate(&self, value: D) -> MembershipDegree<M>
pub fn evaluate(&self, value: D) -> MembershipDegree<M>
Evaluates the membership degree for a given domain value.